@@ -36,6 +36,11 @@ from statsmodels.stats.multitest import fdrcorrection
 from switchlang import switch
 
 
+def _raise_exception(exception_message: str):
+    """Raise exception for invalid classifier input."""
+    raise Exception(exception_message)
+
+
 @dataclass
 class Params:
     """Type signature for random forest and logistic regression parameters.
@@ -68,11 +73,6 @@ class Params:
     random_state: int | None = None
 
 
-def _raise_exception(exception_message: str):
-    """Raise exception for invalid classifier input."""
-    raise Exception(exception_message)
-
-
 class Augurpy:
     """Python implementation of Augur."""
 
@@ -193,7 +193,7 @@ class Augurpy:
                 "logistic_regression_classifier",
                 lambda: LogisticRegression(penalty=params.penalty, random_state=params.random_state),
             )
-            c.default(lambda: _raise_exception("Missing valid input."))
+            c.default(lambda: _raise_exception("Invalid classifer."))
 
         return c.result
 
